@@ -1,12 +1,12 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * goffice-component.h :  
+ * goffice-component.h :
  *
  * Copyright (C) 2005 Jean Brefort (jean.brefort@normalesup.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,7 +28,11 @@ G_BEGIN_DECLS
 
 typedef struct _GOComponent GOComponent;
 typedef struct _GOComponentType GOComponentType;
+typedef struct _GOComponentMimeDialog GOComponentMimeDialog;
 
+#include <goffice/component/go-component.h>
+#include <goffice/component/go-component-factory.h>
+#include <goffice/component/go-component-mime-dialog.h>
 G_END_DECLS
 
 #endif	/* GOFFICE_COMPONENT_H */
